@@ -7,9 +7,8 @@ from tvmbase.client import Client
 
 class BaseTvm(ABC):
 
-    def __init__(self, client: Client, idx: str):
+    def __init__(self, idx: str):
         self.idx = idx
-        self.client = client
 
     @classmethod
     async def from_idx(cls, client: Client, idx: str) -> 'BaseTvm':
@@ -25,7 +24,7 @@ class BaseTvm(ABC):
     @classmethod
     async def from_query_result(cls, client: Client, idx: str, result: ResultOfQueryCollection) -> 'BaseTvm':
         boc = result.result[0]['boc']
-        return await cls.from_boc(client, boc, idx=idx)
+        return await cls.from_boc(client, boc)
 
     @classmethod
     @abstractmethod
