@@ -7,8 +7,8 @@ from tvmbase.models.tvm.base import BaseTvm
 
 class Message(BaseTvm):
 
-    def __init__(self, client: Client, idx: str, data: MessageData):
-        super().__init__(client, idx)
+    def __init__(self, idx: str, data: MessageData):
+        super().__init__(idx)
         self.data = data
 
     @staticmethod
@@ -30,7 +30,6 @@ class Message(BaseTvm):
         return await cls.from_boc(
             client,
             boc,
-            idx=idx,
             created_at=created_at,
             dst_transaction_id=dst_transaction_id,
             src_transaction_id=src_transaction_id,
@@ -51,4 +50,4 @@ class Message(BaseTvm):
         assert 'created_at' not in kwargs or created_at is None or created_at == kwargs['created_at'], \
             f'Different created at time in message {idx}'
         data = MessageData(**parsed.parsed, **kwargs)
-        return cls(client, idx, data)
+        return cls(idx, data)
